==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/LinkedAccessCheckArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.LinkedAccessCheckArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property actionName
 * @property linkedAction
 * @property linkedActionVerb
 * @property linkedProperty
 * @property linkedType
 */
public data class LinkedAccessCheckArgs(
    public val actionName: Output<String>? = null,
    public val linkedAction: Output<String>? = null,
    public val linkedActionVerb: Output<String>? = null,
    public val linkedProperty: Output<String>? = null,
    public val linkedType: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.LinkedAccessCheckArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.LinkedAccessCheckArgs =
        com.pulumi.azurenative.providerhub.inputs.LinkedAccessCheckArgs.builder()
            .actionName(actionName?.applyValue({ args0 -> args0 }))
            .linkedAction(linkedAction?.applyValue({ args0 -> args0 }))
            .linkedActionVerb(linkedActionVerb?.applyValue({ args0 -> args0 }))
            .linkedProperty(linkedProperty?.applyValue({ args0 -> args0 }))
            .linkedType(linkedType?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LinkedAccessCheckArgs].
 */
@PulumiTagMarker
public class LinkedAccessCheckArgsBuilder internal constructor() {
    private var actionName: Output<String>? = null

    private var linkedAction: Output<String>? = null

    private var linkedActionVerb: Output<String>? = null

    private var linkedProperty: Output<String>? = null

    private var linkedType: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("caqvgdbweeoyitkp")
    public suspend fun actionName(`value`: Output<String>) {
        this.actionName = value
    }

    /**
     * @param value
     */
    @JvmName("sbgyieggwxaxkkki")
    public suspend fun linkedAction(`value`: Output<String>) {
        this.linkedAction = value
    }

    /**
     * @param value
     */
    @JvmName("kkeqdyiswcaadwrp")
    public suspend fun linkedActionVerb(`value`: Output<String>) {
        this.linkedActionVerb = value
    }

    /**
     * @param value
     */
    @JvmName("wfesxkfapcqfwran")
    public suspend fun linkedProperty(`value`: Output<String>) {
        this.linkedProperty = value
    }

    /**
     * @param value
     */
    @JvmName("nseuanithiebqqed")
    public suspend fun linkedType(`value`: Output<String>) {
        this.linkedType = value
    }

    /**
     * @param value
     */
    @JvmName("lwpyjsxwvfsvldyk")
    public suspend fun actionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionName = mapped
    }

    /**
     * @param value
     */
    @JvmName("tmcnbdtyucekjmmy")
    public suspend fun linkedAction(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedAction = mapped
    }

    /**
     * @param value
     */
    @JvmName("ieocqashukykhfjx")
    public suspend fun linkedActionVerb(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedActionVerb = mapped
    }

    /**
     * @param value
     */
    @JvmName("yhakbaxbwsiggnjv")
    public suspend fun linkedProperty(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedProperty = mapped
    }

    /**
     * @param value
     */
    @JvmName("bknhyyjfnahvilui")
    public suspend fun linkedType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedType = mapped
    }

    internal fun build(): LinkedAccessCheckArgs = LinkedAccessCheckArgs(
        actionName = actionName,
        linkedAction = linkedAction,
        linkedActionVerb = linkedActionVerb,
        linkedProperty = linkedProperty,
        linkedType = linkedType,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/LinkedAccessCheckArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.LinkedAccessCheckArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property actionName
 * @property linkedAction
 * @property linkedActionVerb
 * @property linkedProperty
 * @property linkedType
 */
public data class LinkedAccessCheckArgs(
    public val actionName: Output<String>? = null,
    public val linkedAction: Output<String>? = null,
    public val linkedActionVerb: Output<String>? = null,
    public val linkedProperty: Output<String>? = null,
    public val linkedType: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.LinkedAccessCheckArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.LinkedAccessCheckArgs =
        com.pulumi.azurenative.providerhub.inputs.LinkedAccessCheckArgs.builder()
            .actionName(actionName?.applyValue({ args0 -> args0 }))
            .linkedAction(linkedAction?.applyValue({ args0 -> args0 }))
            .linkedActionVerb(linkedActionVerb?.applyValue({ args0 -> args0 }))
            .linkedProperty(linkedProperty?.applyValue({ args0 -> args0 }))
            .linkedType(linkedType?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LinkedAccessCheckArgs].
 */
@PulumiTagMarker
public class LinkedAccessCheckArgsBuilder internal constructor() {
    private var actionName: Output<String>? = null

    private var linkedAction: Output<String>? = null

    private var linkedActionVerb: Output<String>? = null

    private var linkedProperty: Output<String>? = null

    private var linkedType: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("wlrompaolsehllan")
    public suspend fun actionName(`value`: Output<String>) {
        this.actionName = value
    }

    /**
     * @param value
     */
    @JvmName("iblvqadkelhwjuwe")
    public suspend fun linkedAction(`value`: Output<String>) {
        this.linkedAction = value
    }

    /**
     * @param value
     */
    @JvmName("axsjgtvwtbugdyyg")
    public suspend fun linkedActionVerb(`value`: Output<String>) {
        this.linkedActionVerb = value
    }

    /**
     * @param value
     */
    @JvmName("axmdgoptruprodod")
    public suspend fun linkedProperty(`value`: Output<String>) {
        this.linkedProperty = value
    }

    /**
     * @param value
     */
    @JvmName("cajfruvaylppekrm")
    public suspend fun linkedType(`value`: Output<String>) {
        this.linkedType = value
    }

    /**
     * @param value
     */
    @JvmName("bkthhieqmsmqnfks")
    public suspend fun actionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actionName = mapped
    }

    /**
     * @param value
     */
    @JvmName("ngbcqcqaxlwxnxib")
    public suspend fun linkedAction(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedAction = mapped
    }

    /**
     * @param value
     */
    @JvmName("lhsqxitahqwqmelq")
    public suspend fun linkedActionVerb(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedActionVerb = mapped
    }

    /**
     * @param value
     */
    @JvmName("rotxfccrrlatqial")
    public suspend fun linkedProperty(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedProperty = mapped
    }

    /**
     * @param value
     */
    @JvmName("gtoisjbfnuatmonr")
    public suspend fun linkedType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.linkedType = mapped
    }

    internal fun build(): LinkedAccessCheckArgs = LinkedAccessCheckArgs(
        actionName = actionName,
        linkedAction = linkedAction,
        linkedActionVerb = linkedActionVerb,
        linkedProperty = linkedProperty,
        linkedType = linkedType,
    )
}
